require 'omniauth-oauth2'

module OmniAuth
  module Strategies
    class PopUpTalent < OmniAuth::Strategies::OAuth2
      DEFAULT_HOST = "https://accounts.popuptalent.com"
      option :name, "pop_up_talent"

      uid { raw_info['id'].to_s }

      info do
        {
          'name' => raw_info['name'],
          'email' => raw_info['email'],
          'created_at' => raw_info['created_at']
        }
      end

      def self.invalidate_sessions!(opts = {})
        key = opts.fetch(:key)
        secret = opts.fetch(:secret)
        host = opts.fetch(:host, DEFAULT_HOST)
        token = opts.fetch(:token)

        client = ::OAuth2::Client.new(key, secret, site: host)
        access_token = ::OAuth2::AccessToken.new(client, token, mode: :query, param_name: :oauth_token)
        access_token.delete('/current_session')
      end

      def initialize(app, opts = {})
        super(app, opts[:key], opts[:secret])

        host = opts[:host] || DEFAULT_HOST
        options[:client_options][:site] = host
        options[:client_options][:token_url] = "#{host}/oauth/authorize"
      end

      def raw_info
        access_token.options[:mode] = :query
        access_token.options[:param_name] = 'oauth_token'
        @raw_info ||= access_token.get('me').parsed
      end
    end
  end
end
